local assets =
{
    Asset("ANIM", "anim/moondial.zip"),
    Asset("ANIM", "anim/moondial_build.zip"),
    Asset("ANIM", "anim/moondial_waning_build.zip"),
}

local prefabs =
{
    "rock_break_fx",
}

local lightstates =
{
	new					= {override=0.00,	enabled=false,	radius=0.00},
	quarter				= {override=0.00,	enabled=false,	radius=0.00},
	half				= {override=0.10,	enabled=true,	radius=0.70},
	threequarter		= {override=0.10,	enabled=true,	radius=1.50},
	full				= {override=0.50,	enabled=true,	radius=5.00},
}

local function onmoonphasechagned(inst, phase)
	if GetClock():GetMoonPhase() ~= "new" or GetClock():GetMoonPhase() == "full" then
		inst.AnimState:ClearOverrideSymbol("reflection_quarter")
		inst.AnimState:ClearOverrideSymbol("reflection_half")
		inst.AnimState:ClearOverrideSymbol("reflection_threequarter")
	else
	    inst.AnimState:OverrideSymbol("reflection_quarter", "moondial_waning_build", "reflection_quarter")
	    inst.AnimState:OverrideSymbol("reflection_half", "moondial_waning_build", "reflection_half")
	    inst.AnimState:OverrideSymbol("reflection_threequarter", "moondial_waning_build", "reflection_threequarter")
	end
	local lightstate = lightstates[GetClock():GetMoonPhase()]
	inst.AnimState:SetLightOverride(lightstate.override)
    inst.Light:Enable(lightstate.enabled)
    inst.Light:SetRadius(lightstate.radius)
    if phase ~= nil and inst.phase ~= GetClock():GetMoonPhase() then
		inst.sg:GoToState("next")
		inst.phase = GetClock():GetMoonPhase()
	end
end

local function onhammered(inst)
    inst.components.lootdropper:DropLoot()
    SpawnPrefab("collapse_small").Transform:SetPosition(inst.Transform:GetWorldPosition())
	inst.SoundEmitter:PlaySound("dontstarve/common/destroy_wood")
    inst:Remove()
end

local function getstatus(inst, viewer)
	return GetWorld():HasTag("cave") and "CAVE"
			or (GetWorld().state.moonphase == "full" and viewer:HasTag("beaverness")) and "WEREBEAVER"
			or (not GetClock():IsNight()) and "GENERIC"
			or GetClock():GetMoonPhase() == "new" and "NIGHT_NEW"
			or GetClock():GetMoonPhase() == "full" and "NIGHT_FULL"
			or GetClock():GetMoonPhase() == "half" and "NIGHT_WAX"
			or "NIGHT_WANE"
end

local function fn()
    local inst = CreateEntity()
    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddMiniMapEntity()
    inst.entity:AddLight()
    MakeObstaclePhysics(inst, .45)
    inst.AnimState:SetBank("moondial")
    inst.AnimState:SetBuild("moondial_build")
    inst.AnimState:PlayAnimation("idle_new")
    inst.MiniMapEntity:SetIcon("moondial.tex")	
	
	inst:AddTag("structure")

    inst.Light:Enable(false)
    inst.Light:SetFalloff(.7)
    inst.Light:SetIntensity(0.6)
    inst.Light:SetColour(15 / 255, 160 / 255, 180 / 255)

	inst:AddComponent("workable")
    inst.components.workable:SetWorkAction(ACTIONS.HAMMER)
    inst.components.workable:SetWorkLeft(8)
    inst.components.workable:SetOnFinishCallback(onhammered)

    inst:AddComponent("inspectable")
    --inst.components.inspectable.getstatus = getstatus

    inst:AddComponent("lootdropper")

	inst:ListenForEvent("daytime", function() onmoonphasechagned(inst,1) end , GetWorld())
	inst:ListenForEvent("dusktime", function() onmoonphasechagned(inst,1) end , GetWorld())
	inst:ListenForEvent("nighttime", function() onmoonphasechagned(inst,1) end , GetWorld())
	onmoonphasechagned(inst)

    inst:SetStateGraph("SGmoondial")
	
	inst.OnSave = function(inst, data)
		if inst.phase then 
			data.phase = inst.phase
		end
    end   
    inst.OnLoad = function(inst, data) 
		if data and data.phase then
			inst.phase = data.phase
		end
    end
    return inst
end

STRINGS.NAMES.MOONDIAL = "Moondial"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.MOONDIAL = "Beautiful! It can predict the next moon!"
STRINGS.RECIPE_DESC.MOONDIAL = "Reflect the coming moon."

return Prefab("moondial", fn, assets, prefabs),
       MakePlacer("moondial_placer", "moondial", "moondial_build", "idle_new")