require("stategraphs/commonstates")

--moondial_full_LP
--moondial_place
local function FillSound(inst)
	local snd = math.random(1,4)
	inst.SoundEmitter:PlaySound("moondial/moondial/moondial_fill_2_" .. snd)
end

local function HitSound(inst)
	local snd = math.random(1,8)
	inst.SoundEmitter:PlaySound("moondial/moondial/moondial_hit_" .. snd)
end

local function WaterSound(inst)
	local snd = math.random(1,5)
	inst.SoundEmitter:PlaySound("moondial/moondial/moondial_water_movement_" .. snd)
end

local actionhandlers =
{
}

local events =
{
    EventHandler("worked", function(inst) inst.sg:GoToState("hit") end),
    EventHandler("onbuilt", function(inst) inst.sg:GoToState("placed") end),
}

local function CalcPhaseAnimName(anim)
	return anim.."_"..GetClock():GetMoonPhase()
end

local function CalcTransitionAnimName()
	if GetClock():GetMoonPhase() == "full" then
		return "wax_to_full"
	elseif GetClock():GetMoonPhase() == "new" then
		return "wane_to_new"
	end
	return (math.random() > 0.5 and "wax" or "wane").."_to_"..GetClock():GetMoonPhase()
end

local states =
{
	State
	{
		name = "idle",
        onenter = function(inst)
			inst.AnimState:PlayAnimation(CalcPhaseAnimName("idle"), true)
			if GetClock():GetMoonPhase() == "full" then
				inst.SoundEmitter:PlaySound("moondial/moondial/moondial_full_LP", "loop")
			else
				inst.SoundEmitter:KillSound("loop")
			end
        end,
		onexit = function(inst)
			inst.SoundEmitter:KillSound("loop")
		end,
    },
    
	State{
		name = "next",

        onenter = function(inst)
			inst.AnimState:PlayAnimation(CalcTransitionAnimName())
        end,

		timeline=
        {
			TimeEvent(4*FRAMES, function(inst) FillSound(inst) end),
        },

        events=
        {
            EventHandler("animover", function(inst) if inst.AnimState:AnimDone() then inst.sg:GoToState("idle") end end),
        },
    },
    
	State{
		name = "hit",

        onenter = function(inst)
            inst.AnimState:PlayAnimation(CalcPhaseAnimName("hit"))
			 HitSound(inst)
        end,

		timeline=
        {
			TimeEvent(9*FRAMES, function(inst) WaterSound(inst) end),
        },

        events=
        {
            EventHandler("animover", function(inst) if inst.AnimState:AnimDone() then inst.sg:GoToState("idle") end end),
        },
    },

	State{
		name = "placed",

        onenter = function(inst)
            inst.AnimState:PlayAnimation(CalcPhaseAnimName("place"))
        end,

		timeline=
        {
			TimeEvent(5*FRAMES, function(inst) inst.SoundEmitter:PlaySound("moondial/moondial/moondial_place") end),
			TimeEvent(7*FRAMES, function(inst) if GetClock():GetMoonPhase() ~= "new" then WaterSound(inst) end end),
        },

        events=
        {
            EventHandler("animover", function(inst) if inst.AnimState:AnimDone() then inst.sg:GoToState("idle") end end),
        },
    },
    
}

return StateGraph("shadow_bishop", states, events, "idle", actionhandlers)

